#!/bin/bash
#-- lecho function shows [PASS]/[FAIL] at end of line ------------------------#
message=""
lecho()
{ chars=$(echo $message | wc -c)
  let "remChars=75 - $chars"
  spaces=""
  while [ "$remChars" -ne "2" ]
  do
    spaces="$spaces "
    let remChars=remChars-1
  done
  echo -n "$spaces"
  if [ $1 -ne 0 ]; then
    echo -en "[\033[1;31mFAIL\033[0m]\n"
  else
    echo -en "[\033[1;32mPASS\033[0m]\n"
  fi
}

#--------------------------------------------------------------------------#
pd="$(pwd)"

#-----------------------------------------------------------------------------#
if [ $(id -u) != 0 ]; then
  echo -e "ERROR: Must be superuser (root) to run the Build script.\n"
  exit 1
fi
   

#-- Check for a 64 bit system ---------------------------------------------#
if [ `arch` = "x86_64" ] ; then
echo Building 32 bit program on 64 bit system
  if [ -f /usr/local/lib/i386/lib/libusb-1.0.so ] ; then
    echo -en "32 bit libusb exists. Re-build required  [y/n] : "
    read resp
  else
    resp=Y
  fi

  if [ "$resp" = "y" ] || [ "$resp" = "Y" ] ; then
    message="(Re)building 32 bit libusb ..."
    echo -n $message
    cd PayLink
    rm -rf libusb-1.0.20
    tar -zxf libusb-1.0.20.tar.gz
    cd libusb-1.0.20
    sh ./configure  --disable-udev --prefix /usr/local/lib/i386 CFLAGS="-m32 -g -O2" 1>/dev/null
    if [ "$?" = "0" ] ; then
      make 1>/dev/null
      if [ "$?" = "0" ] ; then
        make install 1>/dev/null 2>&1
        lecho $?
      else
        echo "libusb - Install Error"
        exit 1
      fi
    else
      echo "libusb - Build Error"
      exit 1
    fi

    ### Now we need to tell Linux about the new 32 bit so
    if [ -d /etc/ld.so.conf.d ] ; then
       # Standard condition, /etc/ld.so.conf.d is directory
       if [ -f /etc/ld.so.conf.d/local_lib_i386.conf ]  ; then
          # /etc/ld.so.conf.d/local_lib_i386.conf is already there
          if grep "^/usr/local/lib/i386/lib" /etc/ld.so.conf.d/local_lib_i386.conf >/dev/null ; then
             : and /usr/local/lib/i386/lib is in it
          else
             # someone else created it - we need to add /usr/local/lib/i386/lib
            echo                         >>/etc/ld.so.conf.d/local_lib_i386.conf
            echo /usr/local/lib/i386/lib >>/etc/ld.so.conf.d/local_lib_i386.conf
          fi
       else
             # Standard condition, we should create local_lib_i386.conf
            echo /usr/local/lib/i386/lib >>/etc/ld.so.conf.d/local_lib_i386.conf
       fi
       ldconfig
    elif [ -f /etc/ld.so.conf ] ; then
       # /etc/ld.so.conf is present, so we assume we can update it
       if grep "^/usr/local/lib/i386/lib" /etc/ld.so.conf >/dev/null ; then
          : /usr/local/lib/i386/lib is already there
       else
          # we need to add /usr/local/lib/i386/lib
          echo                         >>/etc/ld.so.conf
          echo /usr/local/lib/i386/lib >>/etc/ld.so.conf
       fi
       ldconfig
    else
       # the best we can do
       ldconfig /usr/local/lib/i386/lib
    fi

    cd $pd
    rm -r PayLink/libusb-1.0.20
  fi  
fi

#-- Build AES Driver Executable ---------------------------------------------#
message="Building Paylink USB Driver Executable ..."
echo -n $message
cd PayLink/USB\ Driver/
make Paylink 1>/dev/null
if [ "$?" = "0" ] ; then
    make install 1>/dev/null
fi
lecho $?

cd $pd

echo ""
